@@ -12,8 +12,8 @@ class ca_la_expectant_parent_payment_eligible(Variable):
         pregnancy_month = person("current_pregnancy_month", period)
         p = parameters(period).gov.local.ca.la.dss.expectant_parent_payment
         eligible_based_on_pregnancy_month = (
-            p.pregnancy_month.min <= pregnancy_month <= p.pregnancy_month.max
-        )
+            pregnancy_month >= p.pregnancy_month.min
+        ) & (pregnancy_month <= p.pregnancy_month.max)
         foster_care_minor_dependent = person(
             "ca_foster_care_minor_dependent", period
         )
